diff --git a/contrib/dict_int/dict_int.c b/contrib/dict_int/dict_int.c
index 56cb283..4111d6a 100644
--- a/contrib/dict_int/dict_int.c
+++ b/contrib/dict_int/dict_int.c
@@ -21,6 +21,7 @@ typedef struct
 {
 	int			maxlen;
 	bool		rejectlong;
+	bool		absval;
 } DictInt;
 
 
@@ -37,6 +38,7 @@ dintdict_init(PG_FUNCTION_ARGS)
 	d = (DictInt *) palloc0(sizeof(DictInt));
 	d->maxlen = 6;
 	d->rejectlong = false;
+	d->absval = false;
 
 	foreach(l, dictoptions)
 	{
@@ -55,6 +57,10 @@ dintdict_init(PG_FUNCTION_ARGS)
 		{
 			d->rejectlong = defGetBoolean(defel);
 		}
+		else if (strcmp(defel->defname, "absval") == 0)
+		{
+			d->absval = defGetBoolean(defel);
+		}
 		else
 		{
 			ereport(ERROR,
@@ -72,10 +78,20 @@ dintdict_lexize(PG_FUNCTION_ARGS)
 {
 	DictInt    *d = (DictInt *) PG_GETARG_POINTER(0);
 	char	   *in = (char *) PG_GETARG_POINTER(1);
-	char	   *txt = pnstrdup(in, PG_GETARG_INT32(2));
+	int		    len = PG_GETARG_INT32(2);
+	char	   *txt;
 	TSLexeme   *res = palloc0(sizeof(TSLexeme) * 2);
 
 	res[1].lexeme = NULL;
+
+	if (d->absval && (in[0]=='+' || in[0]=='-'))
+	{
+		len--;
+		txt = pnstrdup(in+1, len);
+	}
+	else
+		txt = pnstrdup(in, len);
+	
 	if (PG_GETARG_INT32(2) > d->maxlen)
 	{
 		if (d->rejectlong)
diff --git a/contrib/dict_int/expected/dict_int.out b/contrib/dict_int/expected/dict_int.out
index 483e700..702f7af 100644
--- a/contrib/dict_int/expected/dict_int.out
+++ b/contrib/dict_int/expected/dict_int.out
@@ -302,3 +302,28 @@ select ts_lexize('intdict', '314532610153');
 
 ALTER TEXT SEARCH DICTIONARY intdict (MAXLEN = -214783648);
 ERROR:  maxlen value has to be >= 1
+select ts_lexize('intdict', '-40865854');
+ ts_lexize 
+-----------
+ {-40865}
+(1 row)
+
+select ts_lexize('intdict', '+40865854');
+ ts_lexize 
+-----------
+ {+40865}
+(1 row)
+
+ALTER TEXT SEARCH DICTIONARY intdict (ABSVAL = true);
+select ts_lexize('intdict', '-40865854');
+ ts_lexize 
+-----------
+ {408658}
+(1 row)
+
+select ts_lexize('intdict', '+40865854');
+ ts_lexize 
+-----------
+ {408658}
+(1 row)
+
diff --git a/contrib/dict_int/sql/dict_int.sql b/contrib/dict_int/sql/dict_int.sql
index 5c27acc..8f702aa 100644
--- a/contrib/dict_int/sql/dict_int.sql
+++ b/contrib/dict_int/sql/dict_int.sql
@@ -53,3 +53,9 @@ select ts_lexize('intdict', '641439323669');
 select ts_lexize('intdict', '314532610153');
 
 ALTER TEXT SEARCH DICTIONARY intdict (MAXLEN = -214783648);
+
+select ts_lexize('intdict', '-40865854');
+select ts_lexize('intdict', '+40865854');
+ALTER TEXT SEARCH DICTIONARY intdict (ABSVAL = true);
+select ts_lexize('intdict', '-40865854');
+select ts_lexize('intdict', '+40865854');
diff --git a/doc/src/sgml/dict-int.sgml b/doc/src/sgml/dict-int.sgml
index b556f1b..a659594 100644
--- a/doc/src/sgml/dict-int.sgml
+++ b/doc/src/sgml/dict-int.sgml
@@ -25,7 +25,7 @@
   <title>Configuration</title>
 
   <para>
-   The dictionary accepts two options:
+   The dictionary accepts three options:
   </para>
 
   <itemizedlist>
@@ -45,7 +45,14 @@
      word, so that it will not be indexed.  Note that this also means that
      such an integer cannot be searched for.
     </para>
-   </listitem>
+   </listitem> 
+   <listitem>
+    <para>
+     The <literal>absval</literal> parameter specifies whether a leading
+     '+' or '-' sign should be removed from the integer.  The default is <literal>false</literal>.
+     If <literal>true</literal>, the sign is removed before <literal>maxlen</literal> is applied.
+    </para>
+   </listitem> 
   </itemizedlist>
  </sect2>
 
